@@ -76,6 +76,12 @@ link_function.lm <- function(x, ...) {
 #' @export
 link_function.lme <- link_function.lm
 
+#' @export
+link_function.lqmm <- link_function.lm
+
+#' @export
+link_function.lqm <- link_function.lm
+
 #' @export
 link_function.bayesx <- link_function.lm
 
@@ -337,6 +343,13 @@ link_function.logitor <- link_function.logitmfx
 
 
 
+#' @export
+link_function.mipo <- function(x, ...) {
+  models <- eval(x$call$object)
+  link_function(models$analyses[[1]])
+}
+
+
 #' @export
 link_function.robmixglm <- function(x, ...) {
   switch(
