@@ -131,6 +131,12 @@ link_inverse.lm <- function(x, ...) {
 #' @export
 link_inverse.bayesx <- link_inverse.lm
 
+#' @export
+link_inverse.lqmm <- link_inverse.lm
+
+#' @export
+link_inverse.lqm <- link_inverse.lm
+
 #' @export
 link_inverse.biglm <- link_inverse.lm
 
@@ -663,6 +669,12 @@ link_inverse.gam <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.mipo <- function(x, ...) {
+  models <- eval(x$call$object)
+  link_inverse(models$analyses[[1]])
+}
+
 
 
 
