@@ -216,6 +216,12 @@ model_info.lm_robust <- model_info.mmclogit
 #' @export
 model_info.iv_robust <- model_info.mmclogit
 
+#' @export
+model_info.lqmm <- model_info.mmclogit
+
+#' @export
+model_info.lqm <- model_info.mmclogit
+
 #' @export
 model_info.felm <- model_info.mmclogit
 
@@ -1065,6 +1071,19 @@ model_info.gamlss <- function(x, ...) {
 }
 
 
+#' @export
+model_info.mipo <- function(x, ...) {
+  models <- eval(x$call$object)
+  model_info(models$analyses[[1]], ...)
+}
+
+
+#' @export
+model_info.mira <- function(x, ...) {
+  model_info(x$analyses[[1]], ...)
+}
+
+
 
 
 
