@@ -1,7 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("estimatr")) {
-  context("insight, model_info")
 
   data(mtcars)
   m1 <- iv_robust(mpg ~ gear + cyl | carb + wt, data = mtcars)
@@ -102,7 +101,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "gear", "cyl")
     )
   })
